#!/usr/bin/python
#
# Simple Python script to request asteroids from Skytbot3d Web service.
# You can swith to comets, or planets, or all Sso by invoking, respectively, 
# methods getComet_query.php, getPlanet_query.php or getSso_query.php.
# More info: http://vo.imcce.fr/webservices/skybot3d/
# (C) 2014-2016 IMCCE, J. Normand, J. Berthier
#

import sys
import getopt
import httplib

def usage():
   print "usage: " + sys.argv[0] + " [options]"
   print ""
   print "options:"
   print "  -h, --help        Show this message"
   print "  -c, --coord       Type of coordinates: rectangular (x,y,z) or spherical (RA, DEC) (default to spherical)"
   print "  -d, --date        Set the date in julian day (default to now)"
   print "  -f, --class       Object class (default to all)"
   print "  -g, --get         Set to 1 to get directly the data, else gets the URL to download the data (default to 1)"
   print "  -l, --limit       Number of asteroid to be returned (default to all)"
   print "  -m, --mime        Mime type of the result (votable|text|json, default to json)"
   

def build_uri(coord, date, class, get, limit, mime):
   uri = "/webservices/skybot3d/getAster_query.php?-from=Skybot3D.PythonScript"
   
   if coord != None:
      uri = uri + "&-coord=" + coord
      
   if date != None:
      uri = uri + "&-ep=" + date
      
   if limit != None:
      uri = uri + "&-limit=" + limit
      
   if class != None:
      uri = uri + "&-class=" + class
      
   if mime != None:
      uri = uri + "&-mime=" + mime
      
   if get != None:
      uri = uri + "&-getFile=" + get

   return uri
   
   
def main():
   try:
      opts, args = getopt.getopt(sys.argv[1:], "hc:d:f:g:l:m:", ["help", "coord=", "date=", "class=", "get=", "limit=", "mime="])
   except getopt.GetoptError, err:
      print str(err)
      usage()
      sys.exit(2)

   coord = "spherical"
   date = "now"
   class = "all"
   get = "1"
   limit = 0
   mime = "json"

   for o, a in opts:
      if o in ("-h", "--help"):
         usage()
         sys.exit()
      elif o in ("-c", "--coord"):
         coord = a
      elif o in ("-d", "--date"):
         date = a
      elif o in ("-f", "--class"):
         class = a
      elif o in ("-g", "--get"):
         get = a
      elif o in ("-l", "--limit"):
         limit = a
      elif o in ("-m", "--mime"):
         mime = a
      else:
         assert False, "unhandled option"

   if date == None:
      usage()
      sys.exit()
      
   uri = build_uri(coord, date, class, get, limit, mime)
   
   # query service
   
   conn = httplib.HTTPConnection("vo.imcce.fr")
   conn.request("GET", uri)
   res = conn.getresponse()
   
   if res.status == 200:
      data = res.read()
      print data
   else:
      print sys.argv[0] + ": Error " + str(res.status), res.reason

   conn.close()


if __name__ == "__main__":
   main()
